# Generated by roxygen2: do not edit by hand

export(BRRAT)
export(export_BRRAT_csv)
export(plot_BRRAT_by_id)
export(plot_BRRAT_population)
export(summarise_BRRAT)
import(MASS)
import(Rcpp)
import(ggplot2)
import(methods)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(ggplot2,aes)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,theme_minimal)
importFrom(rstan,sampling)
importFrom(rstantools,rstan_config)
importFrom(stats,lm)
importFrom(stats,qchisq)
useDynLib(BRRAT, .registration = TRUE)
